<?php

/**
 * Plugin Name: PR-Gateway Connect
 * Plugin URI: http://www.pr-gateway.de
 * Description: Publish your articles on Social Networks & +250 press portals
 * Version: 1.4
 * Author: Thomas Kubik
 */
define('PLUGINVERS', '1.4');

register_activation_hook(__FILE__, 'activate_PRG_Connect');

register_deactivation_hook(__FILE__, 'deactivate_PRG_Connect');

add_action('admin_menu', 'PRGConnectMenu');
add_action('init', 'startSession');
add_action('init', 'updateDB');
add_action('admin_init', 'PRGConnect_init');
add_action('post_submitbox_misc_actions', 'publish_box');

//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

function setFilterSent($userId, $setter) {

    global $wpdb;
    $filterSent = serialize($setter);
    $sqlUpdateFilter = $wpdb->prepare("UPDATE `prg_connect_config` SET `filterSent` = %s WHERE `author_id` = %d", $filterSent, $userId);
    $wpdb->query($sqlUpdateFilter);
}

function getFilterSent($userId) {
    global $wpdb;
    $sql = $wpdb->prepare("SELECT `filterSent` FROM `prg_connect_config` WHERE `author_id` = %d", $userId);
    return unserialize($wpdb->get_var($sql));
}

function activate_PRG_Connect() {
    global $wpdb;
    $sqlCreateFirst = "CREATE TABLE IF NOT EXISTS `prg_connect_sent` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `wpid` bigint(20) unsigned DEFAULT NULL,
  `prgsent` tinyint(1) DEFAULT NULL,
  `twittersent` tinyint(1) DEFAULT NULL,
  `facebooksent` tinyint(1) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";
    $wpdb->query($sqlCreateFirst);

    $langWP = get_locale();
    $lang = 'en';
    if ($langWP == 'de_DE') {
        $lang = 'de';
    }

    $sqlCreateSecond = "CREATE TABLE IF NOT EXISTS `prg_connect_config` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `author_id` int(11) NOT NULL,
  `presse` varchar(64) NOT NULL,
  `fname` varchar(64) NOT NULL,
  `lname` varchar(64) NOT NULL,
  `address` varchar(64) NOT NULL,
  `pc` char(5) NOT NULL,
  `city` varchar(64) NOT NULL,
  `phone` varchar(64) NOT NULL,
  `email` varchar(64) NOT NULL,
  `www` varchar(64) NOT NULL,
  `filterSent` varchar(255) NOT NULL,
  `UserBlogToken` varchar(255) NOT NULL,
  `lang` varchar(5) NOT NULL DEFAULT '$lang',
  PRIMARY KEY (`id`)
	) ENGINE=MyISAM  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;";
    $wpdb->query($sqlCreateSecond);
}

function deactivate_PRG_Connect() {
    global $wpdb;
    $sqlDeleteFirst = 'DROP TABLE IF EXISTS `prg_connect_sent`';
    $wpdb->query($sqlDeleteFirst);
    $sqlDeleteSecond = 'DROP TABLE IF EXISTS `prg_connect_config`';
    $wpdb->query($sqlDeleteSecond);
}

function PRGConnectMenu() {
    global $wpdb;
    $currentUserID = get_current_user_id();
    $sql = $wpdb->prepare("SELECT * FROM `prg_connect_config` WHERE `author_id` = %d", $currentUserID);
    $userExist = $wpdb->get_row($sql);
    if (isset($_GET['prgPluginExtern'])) {
        switch ($_GET['prgPluginExtern']) {
            case 'sendSocialNetworks':
                require_once 'View/sendSocialNetworks.php';
                break;
            case 'sendMessage':
                require_once 'Controller/sendMessage.php';
                break;
            case 'sendToFacebook':
                require_once 'Controller/sendToFacebook.php';
                break;
            case 'sendToTwitter':
                require_once 'Controller/sendToTwitter.php';
                break;
            case 'sendToLinkedin':
                require_once 'Controller/sendToLinkedin.php';
                break;
            case 'sendToGoogleplus':
                require_once 'Controller/sendToGoogleplus.php';
                break;
            case 'sendToTumblr':
                require_once 'Controller/sendToTumblr.php';
                break;
            case 'Login':
                require_once 'View/Login.php';
                break;
            case 'sendPress':
                require_once 'View/sendPress.php';
                break;
            case 'facebookPreview' :
                require_once 'View/facebookPreview.php';
                break;
        }
        exit;
    }

    $pages = array();
    add_menu_page('PR-Gateway Connect', 'Social Connect', 0, 'prg_connect', null, plugins_url('/images/pr-gateway_logo_menu.png', __FILE__));
    $pages[] = add_submenu_page('prg_connect', 'PR-Gateway Connect', 'Dashboard', 0, 'prg_connect', 'prg_connect');
    if (empty($userExist->UserBlogToken)) {
        $url = 'http://www.pr-gateway.de/wpplugin/getToken.php';
        $post = array(
            'id' => $currentUserID,
            'url' => get_option('home'),
        );

        $ch = curl_init();

        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        $resultJson = curl_exec($ch);
        curl_close($ch);

        $result = json_decode($resultJson);

        $sqlInsertUserBlogToken = $wpdb->prepare("INSERT INTO `prg_connect_config` (`author_id`, `filterSent`, `UserBlogToken`) VALUES (%d, 'a:1:{s:3:\"prg\";b:0;}', '$result->token');", $currentUserID);
        $wpdb->query($sqlInsertUserBlogToken);
    }
//    if ($userExist->lang == 'de') {
//        include dirname(__FILE__) . '/languages/de.php';
//    } elseif ($userExist->lang == 'en') {
//        include dirname(__FILE__) . '/languages/en.php';
//    } else {
//        include dirname(__FILE__) . '/languages/en.php';
//    }
    
    $textAll = parse_ini_file('languages/lang.ini', TRUE);
    $text = $textAll[$userExist->lang ? $userExist->lang : 'en'];

    $pages[] = add_submenu_page('prg_connect', $text['SN'], $text['SN'], 0, 'prgconfigsocial', 'prgconfigsocial');
    $pages[] = add_submenu_page('prg_connect', $text['SETTINGS'], $text['SETTINGS'], 0, 'prgpluginconfig', 'prgpluginconfig');

    if (isset($_SESSION['prg_id'])) {
        add_submenu_page('prg_connect', 'Logout', 'Logout', 0, 'prglogout', 'prglogout');
    }

    foreach ($pages as $var) {
        add_action($var, 'addStylesnScripts');
    }
}

if ($_SERVER['PHP_SELF'] == '/wp-admin/post-new.php' || $_SERVER['PHP_SELF'] == '/wp-admin/post.php') {
    wp_enqueue_script('PRGNewPostJS', plugins_url('/js/prg_connect_NewPost.1_0.js', __FILE__));
    wp_enqueue_script('FancyBox', plugins_url('/js/jquery.fancybox-1_3_4.pack.js', __FILE__));
    wp_enqueue_style('FancyBoxStyle', plugins_url('/css/jquery.fancybox-1_3_4.css', __FILE__));
}

function addStylesnScripts() {
    wp_enqueue_style('PRGStyle');
    wp_enqueue_style('FancyBoxStyle');
    wp_enqueue_style('Bootstrap');
    wp_enqueue_script('JQuery');
    wp_enqueue_script('FancyBox');
    wp_enqueue_script('PRGJS');
    wp_enqueue_script('PRGValidate');
    wp_enqueue_script('Bootstrap_full');
}

function prg_connect() {
    require_once 'View/listPosts.php';
}

function prgconfigsocial() {
    require_once 'View/configsocial.php';
}

function prgpluginconfig() {
    require_once 'View/configPlugin.php';
}

function prglogout() {
    session_destroy();
    echo '<meta http-equiv="refresh" content="0; URL=?page=prg_connect">';
}

function startSession() {
    if (!session_id()) {
        session_start();
    }
}

function updateDB() {

    global $wpdb;
    $sqlCheckIssetColumnLang = $wpdb->prepare("SELECT `lang` FROM `prg_connect_config` LIMIT 0,%d", 1);
    $issetColumnLang = $wpdb->get_var($sqlCheckIssetColumnLang);
    if (empty($issetColumnLang)) {
        $langWP = get_locale();
        $lang = 'en';
        if ($langWP == 'de_DE') {
            $lang = 'de';
        }
        $sqlUpdateTableLang = $wpdb->prepare("ALTER TABLE `prg_connect_config` ADD `lang` varchar(5) NOT NULL DEFAULT %s", $lang);
        $wpdb->query($sqlUpdateTableLang);
    }

    $field_array = $wpdb->get_results("SHOW COLUMNS FROM prg_connect_sent");

    foreach ($field_array as $row) {
        $columns[] = $row->Field;
    }

    if (!in_array('linkedinsent', $columns)) {
        mysql_query('ALTER TABLE `prg_connect_sent` ADD `linkedinsent` tinyint(1) DEFAULT NULL');
    }
    if (!in_array('googleplussent', $columns)) {
        mysql_query('ALTER TABLE `prg_connect_sent` ADD `googleplussent` tinyint(1) DEFAULT NULL');
    }
    if (!in_array('tumblrsent', $columns)) {
        mysql_query('ALTER TABLE `prg_connect_sent` ADD `tumblrsent` tinyint(1) DEFAULT NULL');
    }
}

function PRGConnect_init() {

    wp_register_style('PRGStyle', plugins_url('/css/prg_connect.1_0.css', __FILE__));
    wp_register_script('JQuery', plugins_url('/js/jquery.min.1_7.js', __FILE__));
    wp_register_script('FancyBox', plugins_url('/js/jquery.fancybox-1_3_4.pack.js', __FILE__));
    wp_register_style('FancyBoxStyle', plugins_url('/css/jquery.fancybox-1_3_4.css', __FILE__));
    wp_register_script('PRGJS', plugins_url('/js/prg_connect.1_0.js', __FILE__));
    wp_register_script('PRGValidate', plugins_url('/js/jquery.validate.min.1_9.js', __FILE__));
    wp_register_style('Bootstrap', plugins_url('/css/bootstrap-modified.1_0.css', __FILE__));
    wp_register_script('Bootstrap_full', plugins_url('/js/bootstrap.min.3_0_3.js', __FILE__));
}

function publish_box() {
    global $wpdb;
    $currentUserID = get_current_user_id();
    $sql = $wpdb->prepare("SELECT `UserBlogToken`, `lang` FROM `prg_connect_config` WHERE `author_id` = %d", $currentUserID);
    $userExist = $wpdb->get_row($sql);


    require_once dirname(__FILE__) . '/Controller/getTwitterWarrant.php';
    require_once dirname(__FILE__) . '/Controller/getFacebookWarrant.php';
    require_once dirname(__FILE__) . '/Controller/getLinkedinWarrant.php';
//	require_once dirname(__FILE__) . '/Controller/getGoogleplusWarrant.php';
    require_once dirname(__FILE__) . '/Controller/getTumblrWarrant.php';

    $prgTwitterConnect = new PRGTwitterConnect();
    $prgFacebookConnect = new PRGFacebookConnect();
    $prgLinkedinConnect = new PRGLinkedinConnect();
//	$prgGoogleplusConnect = new PRGGoogleplusConnect();
    $prgTumblrConnect = new PRGTumblrConnect();

    $socialNetworkRegistered = false;

    $credsTwitterSecond = json_decode($prgTwitterConnect->verifyCredentialsTwitter($userExist->UserBlogToken));
    if (isset($credsTwitterSecond->screen_name)) {
        $socialNetworkRegistered = true;
    }
    if (!$socialNetworkRegistered) {
        $credsTumblrSecond = json_decode($prgTumblrConnect->verifyCredentialsTumblr($userExist->UserBlogToken));
        if (isset($credsTumblrSecond->response->user->name)) {
            $socialNetworkRegistered = true;
        }
    }

//    if (!$socialNetworkRegistered) {
//        $credsGoogleplusSecond = json_decode($prgGoogleplusConnect->verifyCredentialsGoogleplus($userExist->UserBlogToken));
//        if (!empty($credsGoogleplusSecond)) {
//            $socialNetworkRegistered = true;
//        }
//    }

    if (!$socialNetworkRegistered) {
        $credsLinkedinSecond = json_decode($prgLinkedinConnect->verifyCredentialsLinkedin($userExist->UserBlogToken));
        if (isset($credsLinkedinSecond->{'first-name'})) {
            $socialNetworkRegistered = true;
        }
    }

    if (!$socialNetworkRegistered) {
        $credsFacebookSecond = json_decode($prgFacebookConnect->verifyCredentialsFacebook($userExist->UserBlogToken));
        if (isset($credsFacebookSecond->name)) {
            $socialNetworkRegistered = true;
        }
    }

    $textAll = parse_ini_file('languages/lang.ini', TRUE);
    $text = $textAll[$userExist->lang ? $userExist->lang : 'en'];

    if ($socialNetworkRegistered) {
        echo '<div class="misc-pub-section"><span style="padding: 2px 0 1px 20px; background: url(\'' . plugins_url('/images/pr-gateway_logo_menu.png', __FILE__) . '\') no-repeat left center;"><a href="#" class="openPRGCSocialMediaPoster">' . $text['SEND_SN'] . '</a></span></div>';
    } else {
        echo '<div class="misc-pub-section"><span style="padding: 2px 0 1px 20px; background: url(\'' . plugins_url('/images/pr-gateway_logo_menu.png', __FILE__) . '\') no-repeat left center;"><a href="admin.php?page=prgconfigsocial&status=false">' . $text['SEND_SN'] . '</a></span></div>';
    }
}
